//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tile](index.md)/[code](code.md)

# code

[common]\
val [code](code.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

编号
